from setuptools import setup, find_packages

setup(
    name="freedev",
    version="1.1.2",
    description="This is a library for password-protected decryption using opn. I created it to surprise my friend for his birthday. Please don't delete it",
    author="coorton202",
    author_email="coorton50@gmail.com",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent"
    ],
    python_requires=">=3.6",
)